@@ -18,6 +18,7 @@ from .taskers.explain import ExplainTasker
 from .taskers.set import SetCommandTasker
 from .taskers.execute import ExecuteTasker
 from .taskers.use import UseCommandTasker
+from .taskers.show import ShowCommandTasker
 
 
 class CompilerDialect(Dialect):
@@ -38,6 +39,9 @@ class Compiler(object):
     def compile(self, sql, arguments):
         sql = self.parse_mapping(sql)
         expression = maybe_parse(sql, dialect=CompilerDialect)
+        return self.compile_expression(expression, arguments)
+
+    def compile_expression(self, expression, arguments):
         if isinstance(expression, sqlglot_expressions.Delete):
             return DeleteTasker(self.compile_delete(expression, arguments))
         elif isinstance(expression, (sqlglot_expressions.Union, sqlglot_expressions.Insert, sqlglot_expressions.Select)):
@@ -56,6 +60,8 @@ class Compiler(object):
                 if filename in self.mapping:
                     filename = self.mapping[filename]
                 return ExecuteTasker({"filename": filename})
+            if expression.args["this"].lower() == "show" and self.is_const(expression.args["expression"]):
+                return ShowCommandTasker({"key": self.parse_const(expression.args["expression"])["value"]})
         elif isinstance(expression, sqlglot_expressions.Use):
             use_info = expression.args["this"].args["this"].name
             if use_info in self.mapping:
@@ -139,11 +145,11 @@ class Compiler(object):
             raise SyncanySqlCompileException("unkonw insert expression: " + self.to_sql(expression))
 
         if table_info["db"] == "-" and table_info["name"] == "_":
-            config["output"] = "&.-.&1::id"
+            config["output"] = "&.-.&1::id use I"
         else:
-            update_types = [u for u in ("I", "UI", "UDI", "DI")]
+            update_types = [o for o in table_info["typing_options"] if o.upper() in ("I", "UI", "UDI", "DI")] if table_info["typing_options"] else []
             config["output"] = "".join(["&.", table_info["db"], ".", table_info["name"], "::",
-                                        "id", (" use " + update_types[0]) if update_types else ""])
+                                        "id", (" use " + update_types[0].upper()) if update_types else ""])
 
         if isinstance(expression.args["expression"], (sqlglot_expressions.Select, sqlglot_expressions.Union)):
             select_expression = expression.args["expression"]
@@ -264,6 +270,8 @@ class Compiler(object):
                 column_expression = select_expression
             elif isinstance(select_expression, sqlglot_expressions.Alias):
                 column_alias = select_expression.args["alias"].name if "alias" in select_expression.args else None
+                if column_alias and column_alias in self.mapping:
+                    column_alias = self.mapping[column_alias]
                 if self.is_const(select_expression.args["this"]):
                     const_info = self.parse_const(select_expression.args["this"])
                     config["schema"][column_alias] = self.compile_const(const_info)
@@ -333,13 +341,13 @@ class Compiler(object):
         config["input"] = "".join(["&.", primary_table["db"], ".", primary_table["name"], "::",
                                    "+".join(primary_table["loader_primary_keys"]) if primary_table["loader_primary_keys"] else "id"])
         outputer_type = ""
-        if not isinstance(config["schema"], dict) or [key for key in primary_table["outputer_primary_keys"] if
+        if " use " in config["output"]:
+            outputer_type = " use " + config["output"].split(" use ")[-1]
+        elif not isinstance(config["schema"], dict) or [key for key in primary_table["outputer_primary_keys"] if
                                                       key not in config["schema"]] or not config.get("querys"):
             outputer_type = " use I"
         elif [key for key in config["querys"] if key not in config["schema"]]:
             outputer_type = " use UI"
-        elif " use " in config["output"]:
-            outputer_type = " use " + config["output"].split(" use ")[-1]
         config["output"] = "".join([config["output"].split("::")[0], "::",
                                     "+".join(primary_table["outputer_primary_keys"]) if primary_table["outputer_primary_keys"] else "id",
                                     outputer_type])
@@ -365,13 +373,13 @@ class Compiler(object):
         config["input"] = "".join(["&.", primary_table["db"], ".", primary_table["name"], "::",
                                    "+".join(primary_table["loader_primary_keys"]) if primary_table["loader_primary_keys"] else "id"])
         outputer_type = ""
-        if not isinstance(config["schema"], dict) or [key for key in primary_table["outputer_primary_keys"] if
+        if " use " in config["output"]:
+            outputer_type = " use " + config["output"].split(" use ")[-1]
+        elif not isinstance(config["schema"], dict) or [key for key in primary_table["outputer_primary_keys"] if
                                                       key not in config["schema"]] or not config.get("querys"):
             outputer_type = " use I"
         elif [key for key in config["querys"] if key not in config["schema"]]:
             outputer_type = " use UI"
-        elif " use " in config["output"]:
-            outputer_type = " use " + config["output"].split(" use ")[-1]
         config["output"] = "".join([config["output"].split("::")[0], "::",
                                     "+".join(primary_table["outputer_primary_keys"]) if primary_table["outputer_primary_keys"] else "id",
                                     outputer_type])
@@ -818,6 +826,12 @@ class Compiler(object):
         elif isinstance(expression, sqlglot_expressions.In):
             left_calculater, right_calculater = parse(expression)
             return ["@in", left_calculater, right_calculater]
+        elif isinstance(expression, sqlglot_expressions.Like):
+            left_calculater, right_calculater = parse(expression)
+            if not isinstance(right_calculater, list) or len(right_calculater) != 2 or right_calculater[0] != "#const":
+                raise SyncanySqlCompileException("unkonw having condition: " + self.to_sql(expression))
+            return ["#if", ["@re::match", right_calculater[1].replace("%", ".*").replace(".*.*", "%"), left_calculater],
+                    ["#const", True], ["#const", False]]
         elif isinstance(expression, sqlglot_expressions.Paren):
             return self.compile_having_condition(primary_table, expression.args.get("this"), config)
         else:
