@@ -18,9 +18,9 @@ class UseCommandTasker(object):
                 session_config.set("imports." + use_info[1], use_info[0])
         else:
             if os.path.exists(use_info[0]):
-                session_config.set("sources." + use_info[0], use_info[0])
+                session_config.set("sources." + use_info[0].split(".")[-1], use_info[0])
             else:
-                session_config.set("imports." + use_info[0], use_info[0])
+                session_config.set("imports." + use_info[0].split(".")[-1], use_info[0])
         return []
 
     def run(self, executor, session_config, manager):
